# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class ArtifactLocation(object):
    """Specifies the location of an artifact."""

    description = attr.ib(default=None, metadata={"schema_property_name": "description"})
    index = attr.ib(default=-1, metadata={"schema_property_name": "index"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    uri = attr.ib(default=None, metadata={"schema_property_name": "uri"})
    uri_base_id = attr.ib(default=None, metadata={"schema_property_name": "uriBaseId"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class ArtifactChange(object):
    """A change to a single artifact."""

    artifact_location = attr.ib(metadata={"schema_property_name": "artifactLocation"})
    replacements = attr.ib(metadata={"schema_property_name": "replacements"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class WebRequest(object):
    """Describes an HTTP request."""

    body = attr.ib(default=None, metadata={"schema_property_name": "body"})
    headers = attr.ib(default=None, metadata={"schema_property_name": "headers"})
    index = attr.ib(default=-1, metadata={"schema_property_name": "index"})
    method = attr.ib(default=None, metadata={"schema_property_name": "method"})
    parameters = attr.ib(default=None, metadata={"schema_property_name": "parameters"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    protocol = attr.ib(default=None, metadata={"schema_property_name": "protocol"})
    target = attr.ib(default=None, metadata={"schema_property_name": "target"})
    version = attr.ib(default=None, metadata={"schema_property_name": "version"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class VersionControlDetails(object):
    """Specifies the information necessary to retrieve a desired revision from a version control system."""

    repository_uri = attr.ib(metadata={"schema_property_name": "repositoryUri"})
    as_of_time_utc = attr.ib(default=None, metadata={"schema_property_name": "asOfTimeUtc"})
    branch = attr.ib(default=None, metadata={"schema_property_name": "branch"})
    mapped_to = attr.ib(default=None, metadata={"schema_property_name": "mappedTo"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    revision_id = attr.ib(default=None, metadata={"schema_property_name": "revisionId"})
    revision_tag = attr.ib(default=None, metadata={"schema_property_name": "revisionTag"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class Tool(object):
    """The analysis tool that was run."""

    driver = attr.ib(metadata={"schema_property_name": "driver"})
    extensions = attr.ib(default=None, metadata={"schema_property_name": "extensions"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class Attachment(object):
    """An artifact relevant to a result."""

    artifact_location = attr.ib(metadata={"schema_property_name": "artifactLocation"})
    description = attr.ib(default=None, metadata={"schema_property_name": "description"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    rectangles = attr.ib(default=None, metadata={"schema_property_name": "rectangles"})
    regions = attr.ib(default=None, metadata={"schema_property_name": "regions"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class Message(object):
    """Encapsulates a message intended to be read by the end user."""

    arguments = attr.ib(default=None, metadata={"schema_property_name": "arguments"})
    id = attr.ib(default=None, metadata={"schema_property_name": "id"})
    markdown = attr.ib(default=None, metadata={"schema_property_name": "markdown"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    text = attr.ib(default=None, metadata={"schema_property_name": "text"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class GraphTraversal(object):
    """Represents a path through a graph."""

    description = attr.ib(default=None, metadata={"schema_property_name": "description"})
    edge_traversals = attr.ib(default=None, metadata={"schema_property_name": "edgeTraversals"})
    immutable_state = attr.ib(default=None, metadata={"schema_property_name": "immutableState"})
    initial_state = attr.ib(default=None, metadata={"schema_property_name": "initialState"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    result_graph_index = attr.ib(default=-1, metadata={"schema_property_name": "resultGraphIndex"})
    run_graph_index = attr.ib(default=-1, metadata={"schema_property_name": "runGraphIndex"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class MultiformatMessageString(object):
    """A message string or message format string rendered in multiple formats."""

    text = attr.ib(metadata={"schema_property_name": "text"})
    markdown = attr.ib(default=None, metadata={"schema_property_name": "markdown"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class Artifact(object):
    """A single artifact. In some cases, this artifact might be nested within another artifact."""

    contents = attr.ib(default=None, metadata={"schema_property_name": "contents"})
    description = attr.ib(default=None, metadata={"schema_property_name": "description"})
    encoding = attr.ib(default=None, metadata={"schema_property_name": "encoding"})
    hashes = attr.ib(default=None, metadata={"schema_property_name": "hashes"})
    last_modified_time_utc = attr.ib(default=None, metadata={"schema_property_name": "lastModifiedTimeUtc"})
    length = attr.ib(default=-1, metadata={"schema_property_name": "length"})
    location = attr.ib(default=None, metadata={"schema_property_name": "location"})
    mime_type = attr.ib(default=None, metadata={"schema_property_name": "mimeType"})
    offset = attr.ib(default=None, metadata={"schema_property_name": "offset"})
    parent_index = attr.ib(default=-1, metadata={"schema_property_name": "parentIndex"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    roles = attr.ib(default=None, metadata={"schema_property_name": "roles"})
    source_language = attr.ib(default=None, metadata={"schema_property_name": "sourceLanguage"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class ArtifactContent(object):
    """Represents the contents of an artifact."""

    binary = attr.ib(default=None, metadata={"schema_property_name": "binary"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    rendered = attr.ib(default=None, metadata={"schema_property_name": "rendered"})
    text = attr.ib(default=None, metadata={"schema_property_name": "text"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class CodeFlow(object):
    """A set of threadFlows which together describe a pattern of code execution relevant to detecting a result."""

    thread_flows = attr.ib(metadata={"schema_property_name": "threadFlows"})
    message = attr.ib(default=None, metadata={"schema_property_name": "message"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class LocationRelationship(object):
    """Information about the relation of one location to another."""

    target = attr.ib(metadata={"schema_property_name": "target"})
    description = attr.ib(default=None, metadata={"schema_property_name": "description"})
    kinds = attr.ib(default=attr.Factory(lambda: ['relevant']), metadata={"schema_property_name": "kinds"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
